#[repr(transparent)]pub struct RelativeTimeFormat {
pub obj: JsValue,
}Expand description
The Intl.RelativeTimeFormat object is a constructor for objects
that enable language-sensitive relative time formatting.
Fields
obj: JsValueImplementations
Sourceimpl RelativeTimeFormat
impl RelativeTimeFormat
Sourcepub fn new(locales: &Array, options: &Object) -> RelativeTimeFormat
pub fn new(locales: &Array, options: &Object) -> RelativeTimeFormat
The Intl.RelativeTimeFormat object is a constructor for objects
that enable language-sensitive relative time formatting.
Sourceimpl RelativeTimeFormat
impl RelativeTimeFormat
Sourcepub fn format_to_parts(&self, value: f64, unit: &str) -> Array
pub fn format_to_parts(&self, value: f64, unit: &str) -> Array
The Intl.RelativeTimeFormat.prototype.formatToParts() method returns an array of
objects representing the relative time format in parts that can be used for custom locale-aware formatting.
Sourceimpl RelativeTimeFormat
impl RelativeTimeFormat
Sourcepub fn resolved_options(&self) -> Object
pub fn resolved_options(&self) -> Object
The Intl.RelativeTimeFormat.prototype.resolvedOptions() method returns a new
object with properties reflecting the locale and relative time formatting
options computed during initialization of this RelativeTimeFormat object.
Sourceimpl RelativeTimeFormat
impl RelativeTimeFormat
Sourcepub fn supported_locales_of(locales: &Array, options: &Object) -> Array
pub fn supported_locales_of(locales: &Array, options: &Object) -> Array
The Intl.RelativeTimeFormat.supportedLocalesOf() method returns an array
containing those of the provided locales that are supported in date and time
formatting without having to fall back to the runtime’s default locale.
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.