#[repr(transparent)]pub struct Array {
pub obj: JsValue,
}Fields
obj: JsValueImplementations
Sourceimpl Array
impl Array
Sourcepub fn new_with_length(len: u32) -> Array
pub fn new_with_length(len: u32) -> Array
Creates a new array with the specified length (elements are initialized to undefined).
Sourceimpl Array
impl Array
Sourceimpl Array
impl Array
Sourceimpl Array
impl Array
Sourceimpl Array
impl Array
Sourcepub fn find_last(
&self,
predicate: &mut dyn FnMut(JsValue, u32, Array) -> bool,
) -> JsValue
pub fn find_last( &self, predicate: &mut dyn FnMut(JsValue, u32, Array) -> bool, ) -> JsValue
The findLast() method of Array instances iterates the array in reverse order
and returns the value of the first element that satisfies the provided testing function.
If no elements satisfy the testing function, undefined is returned.
Sourceimpl Array
impl Array
Sourcepub fn find_last_index(
&self,
predicate: &mut dyn FnMut(JsValue, u32, Array) -> bool,
) -> i32
pub fn find_last_index( &self, predicate: &mut dyn FnMut(JsValue, u32, Array) -> bool, ) -> i32
The findLastIndex() method of Array instances iterates the array in reverse order
and returns the index of the first element that satisfies the provided testing function.
If no elements satisfy the testing function, -1 is returned.
Sourceimpl Array
impl Array
Sourceimpl Array
impl Array
Sourceimpl Array
impl Array
Sourceimpl Array
impl Array
Sourcepub fn last_index_of(&self, value: &JsValue, from_index: i32) -> i32
pub fn last_index_of(&self, value: &JsValue, from_index: i32) -> i32
The lastIndexOf() method returns the last index at which a given element
can be found in the array, or -1 if it is not present. The array is
searched backwards, starting at fromIndex.
Sourceimpl Array
impl Array
Sourceimpl Array
impl Array
Sourcepub fn set_length(&self, value: u32)
pub fn set_length(&self, value: u32)
Sets the length of the array.
If it is set to less than the current length of the array, it will shrink the array.
If it is set to more than the current length of the array, it will increase the length of the array, filling the new space with empty slots.
Sourceimpl Array
impl Array
Sourcepub fn map(
&self,
predicate: &mut dyn FnMut(JsValue, u32, Array) -> JsValue,
) -> Array
pub fn map( &self, predicate: &mut dyn FnMut(JsValue, u32, Array) -> JsValue, ) -> Array
map() calls a provided callback function once for each element in an array,
in order, and constructs a new array from the results. callback is invoked
only for indexes of the array which have assigned values, including undefined.
It is not called for missing elements of the array (that is, indexes that have
never been set, which have been deleted or which have never been assigned a value).
Sourceimpl Array
impl Array
Sourcepub fn of1(a: &JsValue) -> Array
pub fn of1(a: &JsValue) -> Array
The Array.of() method creates a new Array instance with a variable
number of arguments, regardless of number or type of the arguments.
The difference between Array.of() and the Array constructor is in the
handling of integer arguments: Array.of(7) creates an array with a single
element, 7, whereas Array(7) creates an empty array with a length
property of 7 (Note: this implies an array of 7 empty slots, not slots
with actual undefined values).
Notes
There are a few bindings to of in js-sys: of1, of2, etc…
with different arities.
Sourceimpl Array
impl Array
Sourceimpl Array
impl Array
Sourceimpl Array
impl Array
Sourceimpl Array
impl Array
Sourceimpl Array
impl Array
Sourceimpl Array
impl Array
Sourcepub fn sort(&self) -> Array
pub fn sort(&self) -> Array
The sort() method sorts the elements of an array in place and returns
the array. The sort is not necessarily stable. The default sort
order is according to string Unicode code points.
The time and space complexity of the sort cannot be guaranteed as it is implementation dependent.
Sourceimpl Array
impl Array
Sourcepub fn to_locale_string(&self, locales: &JsValue, options: &JsValue) -> JsString
pub fn to_locale_string(&self, locales: &JsValue, options: &JsValue) -> JsString
The toLocaleString() method returns a string representing the elements of the array.
The elements are converted to Strings using their toLocaleString methods and these
Strings are separated by a locale-specific String (such as a comma “,”).
Sourceimpl Array
impl Array
Sourceimpl Array
impl Array
Sourceimpl Array
impl Array
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.