DataView

Struct DataView 

#[repr(transparent)]
pub struct DataView { pub obj: JsValue, }

Fields

obj: JsValue

Implementations

Source

impl DataView

pub fn new( buffer: &ArrayBuffer, byteOffset: usize, byteLength: usize, ) -> DataView

The DataView view provides a low-level interface for reading and writing multiple number types in an ArrayBuffer irrespective of the platform’s endianness.

MDN documentation

Source

impl DataView

pub fn new_with_shared_array_buffer( buffer: &SharedArrayBuffer, byteOffset: usize, byteLength: usize, ) -> DataView

The DataView view provides a low-level interface for reading and writing multiple number types in an ArrayBuffer irrespective of the platform’s endianness.

MDN documentation

Source

impl DataView

pub fn buffer(&self) -> ArrayBuffer

The ArrayBuffer referenced by this view. Fixed at construction time and thus read only.

MDN documentation

Source

impl DataView

pub fn byte_length(&self) -> usize

The length (in bytes) of this view from the start of its ArrayBuffer. Fixed at construction time and thus read only.

MDN documentation

Source

impl DataView

pub fn byte_offset(&self) -> usize

The offset (in bytes) of this view from the start of its ArrayBuffer. Fixed at construction time and thus read only.

MDN documentation

Source

impl DataView

pub fn get_int8(&self, byte_offset: usize) -> i8

The getInt8() method gets a signed 8-bit integer (byte) at the specified byte offset from the start of the DataView.

MDN documentation

Source

impl DataView

pub fn get_uint8(&self, byte_offset: usize) -> u8

The getUint8() method gets a unsigned 8-bit integer (byte) at the specified byte offset from the start of the DataView.

MDN documentation

Source

impl DataView

pub fn get_int16(&self, byte_offset: usize) -> i16

The getInt16() method gets a signed 16-bit integer (short) at the specified byte offset from the start of the DataView.

MDN documentation

Source

impl DataView

pub fn get_int16_endian(&self, byte_offset: usize, little_endian: bool) -> i16

The getInt16() method gets a signed 16-bit integer (short) at the specified byte offset from the start of the DataView.

MDN documentation

Source

impl DataView

pub fn get_uint16(&self, byte_offset: usize) -> u16

The getUint16() method gets an unsigned 16-bit integer (unsigned short) at the specified byte offset from the start of the view.

MDN documentation

Source

impl DataView

pub fn get_uint16_endian(&self, byte_offset: usize, little_endian: bool) -> u16

The getUint16() method gets an unsigned 16-bit integer (unsigned short) at the specified byte offset from the start of the view.

MDN documentation

Source

impl DataView

pub fn get_int32(&self, byte_offset: usize) -> i32

The getInt32() method gets a signed 32-bit integer (long) at the specified byte offset from the start of the DataView.

MDN documentation

Source

impl DataView

pub fn get_int32_endian(&self, byte_offset: usize, little_endian: bool) -> i32

The getInt32() method gets a signed 32-bit integer (long) at the specified byte offset from the start of the DataView.

MDN documentation

Source

impl DataView

pub fn get_uint32(&self, byte_offset: usize) -> u32

The getUint32() method gets an unsigned 32-bit integer (unsigned long) at the specified byte offset from the start of the view.

MDN documentation

Source

impl DataView

pub fn get_uint32_endian(&self, byte_offset: usize, little_endian: bool) -> u32

The getUint32() method gets an unsigned 32-bit integer (unsigned long) at the specified byte offset from the start of the view.

MDN documentation

Source

impl DataView

pub fn get_float32(&self, byte_offset: usize) -> f32

The getFloat32() method gets a signed 32-bit float (float) at the specified byte offset from the start of the DataView.

MDN documentation

Source

impl DataView

pub fn get_float32_endian(&self, byte_offset: usize, little_endian: bool) -> f32

The getFloat32() method gets a signed 32-bit float (float) at the specified byte offset from the start of the DataView.

MDN documentation

Source

impl DataView

pub fn get_float64(&self, byte_offset: usize) -> f64

The getFloat64() method gets a signed 64-bit float (double) at the specified byte offset from the start of the DataView.

MDN documentation

Source

impl DataView

pub fn get_float64_endian(&self, byte_offset: usize, little_endian: bool) -> f64

The getFloat64() method gets a signed 64-bit float (double) at the specified byte offset from the start of the DataView.

MDN documentation

Source

impl DataView

pub fn set_int8(&self, byte_offset: usize, value: i8)

The setInt8() method stores a signed 8-bit integer (byte) value at the specified byte offset from the start of the DataView.

MDN documentation

Source

impl DataView

pub fn set_uint8(&self, byte_offset: usize, value: u8)

The setUint8() method stores an unsigned 8-bit integer (byte) value at the specified byte offset from the start of the DataView.

MDN documentation

Source

impl DataView

pub fn set_int16(&self, byte_offset: usize, value: i16)

The setInt16() method stores a signed 16-bit integer (short) value at the specified byte offset from the start of the DataView.

MDN documentation

Source

impl DataView

pub fn set_int16_endian( &self, byte_offset: usize, value: i16, little_endian: bool, )

The setInt16() method stores a signed 16-bit integer (short) value at the specified byte offset from the start of the DataView.

MDN documentation

Source

impl DataView

pub fn set_uint16(&self, byte_offset: usize, value: u16)

The setUint16() method stores an unsigned 16-bit integer (unsigned short) value at the specified byte offset from the start of the DataView.

MDN documentation

Source

impl DataView

pub fn set_uint16_endian( &self, byte_offset: usize, value: u16, little_endian: bool, )

The setUint16() method stores an unsigned 16-bit integer (unsigned short) value at the specified byte offset from the start of the DataView.

MDN documentation

Source

impl DataView

pub fn set_int32(&self, byte_offset: usize, value: i32)

The setInt32() method stores a signed 32-bit integer (long) value at the specified byte offset from the start of the DataView.

MDN documentation

Source

impl DataView

pub fn set_int32_endian( &self, byte_offset: usize, value: i32, little_endian: bool, )

The setInt32() method stores a signed 32-bit integer (long) value at the specified byte offset from the start of the DataView.

MDN documentation

Source

impl DataView

pub fn set_uint32(&self, byte_offset: usize, value: u32)

The setUint32() method stores an unsigned 32-bit integer (unsigned long) value at the specified byte offset from the start of the DataView.

MDN documentation

Source

impl DataView

pub fn set_uint32_endian( &self, byte_offset: usize, value: u32, little_endian: bool, )

The setUint32() method stores an unsigned 32-bit integer (unsigned long) value at the specified byte offset from the start of the DataView.

MDN documentation

Source

impl DataView

pub fn set_float32(&self, byte_offset: usize, value: f32)

The setFloat32() method stores a signed 32-bit float (float) value at the specified byte offset from the start of the DataView.

MDN documentation

Source

impl DataView

pub fn set_float32_endian( &self, byte_offset: usize, value: f32, little_endian: bool, )

The setFloat32() method stores a signed 32-bit float (float) value at the specified byte offset from the start of the DataView.

MDN documentation

Source

impl DataView

pub fn set_float64(&self, byte_offset: usize, value: f64)

The setFloat64() method stores a signed 64-bit float (double) value at the specified byte offset from the start of the DataView.

MDN documentation

Source

impl DataView

pub fn set_float64_endian( &self, byte_offset: usize, value: f64, little_endian: bool, )

The setFloat64() method stores a signed 64-bit float (double) value at the specified byte offset from the start of the DataView.

MDN documentation

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

The constructor property returns a reference to the Object constructor function that created the instance object.

MDN documentation

pub fn has_own_property(&self, property: &JsValue) -> bool

The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).

MDN documentation

pub fn is_prototype_of(&self, value: &JsValue) -> bool

The isPrototypeOf() method checks if an object exists in another object’s prototype chain.

MDN documentation

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.

MDN documentation

pub fn to_locale_string(&self) -> JsString

The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.

MDN documentation

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn value_of(&self) -> Object

The valueOf() method returns the primitive value of the specified object.

MDN documentation

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn id(&self) -> u64

Get the heap ID for this value.

This is used internally for encoding values to send to JS.

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, rhs: &JsValue) -> bool

Less than comparison.

pub fn le(&self, rhs: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, rhs: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, rhs: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, rhs: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.