#[repr(transparent)]pub struct Function {
pub obj: JsValue,
}Fields
obj: JsValueImplementations
Sourceimpl Function
impl Function
Sourcepub fn new_with_args(args: &str, body: &str) -> Function
pub fn new_with_args(args: &str, body: &str) -> Function
The Function constructor creates a new Function object. Calling the
constructor directly can create functions dynamically, but suffers from
security and similar (but far less significant) performance issues
similar to eval. However, unlike eval, the Function constructor
allows executing code in the global scope, prompting better programming
habits and allowing for more efficient code minification.
Sourceimpl Function
impl Function
Sourcepub fn new_no_args(body: &str) -> Function
pub fn new_no_args(body: &str) -> Function
The Function constructor creates a new Function object. Calling the
constructor directly can create functions dynamically, but suffers from
security and similar (but far less significant) performance issues
similar to eval. However, unlike eval, the Function constructor
allows executing code in the global scope, prompting better programming
habits and allowing for more efficient code minification.
Sourceimpl Function
impl Function
Sourceimpl Function
impl Function
Sourceimpl Function
impl Function
Sourcepub fn call9(
&self,
context: &JsValue,
arg1: &JsValue,
arg2: &JsValue,
arg3: &JsValue,
arg4: &JsValue,
arg5: &JsValue,
arg6: &JsValue,
arg7: &JsValue,
arg8: &JsValue,
arg9: &JsValue,
) -> Result<JsValue, JsValue>
pub fn call9( &self, context: &JsValue, arg1: &JsValue, arg2: &JsValue, arg3: &JsValue, arg4: &JsValue, arg5: &JsValue, arg6: &JsValue, arg7: &JsValue, arg8: &JsValue, arg9: &JsValue, ) -> Result<JsValue, JsValue>
The call() method calls a function with a given this value and
arguments provided individually.
Sourceimpl Function
impl Function
Sourceimpl Function
impl Function
Sourceimpl Function
impl Function
Sourceimpl Function
impl Function
Sourcepub fn bind3(
&self,
context: &JsValue,
arg1: &JsValue,
arg2: &JsValue,
arg3: &JsValue,
) -> Function
pub fn bind3( &self, context: &JsValue, arg1: &JsValue, arg2: &JsValue, arg3: &JsValue, ) -> Function
The bind() method creates a new function that, when called, has its this keyword set to the provided value,
with a given sequence of arguments preceding any provided when the new function is called.
Sourceimpl Function
impl Function
Sourcepub fn bind4(
&self,
context: &JsValue,
arg1: &JsValue,
arg2: &JsValue,
arg3: &JsValue,
arg4: &JsValue,
) -> Function
pub fn bind4( &self, context: &JsValue, arg1: &JsValue, arg2: &JsValue, arg3: &JsValue, arg4: &JsValue, ) -> Function
The bind() method creates a new function that, when called, has its this keyword set to the provided value,
with a given sequence of arguments preceding any provided when the new function is called.
Sourceimpl Function
impl Function
Sourcepub fn bind5(
&self,
context: &JsValue,
arg1: &JsValue,
arg2: &JsValue,
arg3: &JsValue,
arg4: &JsValue,
arg5: &JsValue,
) -> Function
pub fn bind5( &self, context: &JsValue, arg1: &JsValue, arg2: &JsValue, arg3: &JsValue, arg4: &JsValue, arg5: &JsValue, ) -> Function
The bind() method creates a new function that, when called, has its this keyword set to the provided value,
with a given sequence of arguments preceding any provided when the new function is called.
Sourceimpl Function
impl Function
Sourcepub fn bind6(
&self,
context: &JsValue,
arg1: &JsValue,
arg2: &JsValue,
arg3: &JsValue,
arg4: &JsValue,
arg5: &JsValue,
arg6: &JsValue,
) -> Function
pub fn bind6( &self, context: &JsValue, arg1: &JsValue, arg2: &JsValue, arg3: &JsValue, arg4: &JsValue, arg5: &JsValue, arg6: &JsValue, ) -> Function
The bind() method creates a new function that, when called, has its this keyword set to the provided value,
with a given sequence of arguments preceding any provided when the new function is called.
Sourceimpl Function
impl Function
Sourcepub fn bind7(
&self,
context: &JsValue,
arg1: &JsValue,
arg2: &JsValue,
arg3: &JsValue,
arg4: &JsValue,
arg5: &JsValue,
arg6: &JsValue,
arg7: &JsValue,
) -> Function
pub fn bind7( &self, context: &JsValue, arg1: &JsValue, arg2: &JsValue, arg3: &JsValue, arg4: &JsValue, arg5: &JsValue, arg6: &JsValue, arg7: &JsValue, ) -> Function
The bind() method creates a new function that, when called, has its this keyword set to the provided value,
with a given sequence of arguments preceding any provided when the new function is called.
Sourceimpl Function
impl Function
Sourcepub fn bind8(
&self,
context: &JsValue,
arg1: &JsValue,
arg2: &JsValue,
arg3: &JsValue,
arg4: &JsValue,
arg5: &JsValue,
arg6: &JsValue,
arg7: &JsValue,
arg8: &JsValue,
) -> Function
pub fn bind8( &self, context: &JsValue, arg1: &JsValue, arg2: &JsValue, arg3: &JsValue, arg4: &JsValue, arg5: &JsValue, arg6: &JsValue, arg7: &JsValue, arg8: &JsValue, ) -> Function
The bind() method creates a new function that, when called, has its this keyword set to the provided value,
with a given sequence of arguments preceding any provided when the new function is called.
Sourceimpl Function
impl Function
Sourcepub fn bind9(
&self,
context: &JsValue,
arg1: &JsValue,
arg2: &JsValue,
arg3: &JsValue,
arg4: &JsValue,
arg5: &JsValue,
arg6: &JsValue,
arg7: &JsValue,
arg8: &JsValue,
arg9: &JsValue,
) -> Function
pub fn bind9( &self, context: &JsValue, arg1: &JsValue, arg2: &JsValue, arg3: &JsValue, arg4: &JsValue, arg5: &JsValue, arg6: &JsValue, arg7: &JsValue, arg8: &JsValue, arg9: &JsValue, ) -> Function
The bind() method creates a new function that, when called, has its this keyword set to the provided value,
with a given sequence of arguments preceding any provided when the new function is called.
Sourceimpl Function
impl Function
Sourceimpl Function
impl Function
Sourceimpl Function
impl Function
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.