#[repr(transparent)]pub struct Int16Array {
pub obj: JsValue,
}Fields
obj: JsValueImplementations
Sourceimpl Int16Array
impl Int16Array
Sourcepub fn new(constructor_arg: &JsValue) -> Int16Array
pub fn new(constructor_arg: &JsValue) -> Int16Array
The
Int16Array()
constructor creates a new array.
Sourceimpl Int16Array
impl Int16Array
Sourcepub fn new_with_length(length: u32) -> Int16Array
pub fn new_with_length(length: u32) -> Int16Array
An
Int16Array()
which creates an array with an internal buffer large
enough for length elements.
Sourceimpl Int16Array
impl Int16Array
Sourcepub fn new_from_slice(slice: &[i16]) -> Int16Array
pub fn new_from_slice(slice: &[i16]) -> Int16Array
An
Int16Array()
which creates an array from a Rust slice.
Sourceimpl Int16Array
impl Int16Array
Sourcepub fn new_with_byte_offset(buffer: &JsValue, byte_offset: u32) -> Int16Array
pub fn new_with_byte_offset(buffer: &JsValue, byte_offset: u32) -> Int16Array
An
Int16Array()
which creates an array with the given buffer but is a
view starting at byte_offset.
Sourceimpl Int16Array
impl Int16Array
Sourcepub fn new_with_byte_offset_and_length(
buffer: &JsValue,
byte_offset: u32,
length: u32,
) -> Int16Array
pub fn new_with_byte_offset_and_length( buffer: &JsValue, byte_offset: u32, length: u32, ) -> Int16Array
An
Int16Array()
which creates an array with the given buffer but is a
view starting at byte_offset for length elements.
Sourceimpl Int16Array
impl Int16Array
Sourceimpl Int16Array
impl Int16Array
Sourcepub fn buffer(&self) -> ArrayBuffer
pub fn buffer(&self) -> ArrayBuffer
The buffer accessor property represents the ArrayBuffer referenced
by a TypedArray at construction time.
Sourceimpl Int16Array
impl Int16Array
Sourcepub fn subarray(&self, begin: u32, end: u32) -> Int16Array
pub fn subarray(&self, begin: u32, end: u32) -> Int16Array
The subarray() method returns a new TypedArray on the same
ArrayBuffer store and with the same element types as for this
TypedArray object.
Sourceimpl Int16Array
impl Int16Array
Sourcepub fn slice(&self, begin: u32, end: u32) -> Int16Array
pub fn slice(&self, begin: u32, end: u32) -> Int16Array
The slice() method returns a shallow copy of a portion of a typed
array into a new typed array object. This method has the same algorithm
as Array.prototype.slice().
Sourceimpl Int16Array
impl Int16Array
Sourceimpl Int16Array
impl Int16Array
Sourceimpl Int16Array
impl Int16Array
Sourcepub fn byte_length(&self) -> u32
pub fn byte_length(&self) -> u32
The byteLength accessor property represents the length (in bytes) of a typed array.
Sourceimpl Int16Array
impl Int16Array
Sourcepub fn byte_offset(&self) -> u32
pub fn byte_offset(&self) -> u32
The byteOffset accessor property represents the offset (in bytes) of a
typed array from the start of its ArrayBuffer.
Sourceimpl Int16Array
impl Int16Array
Sourceimpl Int16Array
impl Int16Array
Sourceimpl Int16Array
impl Int16Array
Sourcepub fn copy_within(&self, target: i32, start: i32, end: i32) -> Int16Array
pub fn copy_within(&self, target: i32, start: i32, end: i32) -> Int16Array
The copyWithin() method shallow copies part of a typed array to another
location in the same typed array and returns it, without modifying its size.
Sourceimpl Int16Array
impl Int16Array
Sourceimpl Int16Array
impl Int16Array
Sourceimpl Int16Array
impl Int16Array
Sourcepub unsafe fn view(rust: &[i16]) -> Int16Array
pub unsafe fn view(rust: &[i16]) -> Int16Array
Creates a JS typed array which is a view into wasm’s linear memory at the slice specified.
This function returns a new typed array which is a view into wasm’s memory. This view does not copy the underlying data.
Safety
Views into WebAssembly memory are only valid so long as the
backing buffer isn’t resized in JS. Once this function is called
any future calls to Box::new (or malloc of any form) may cause
the returned value here to be invalidated. Use with caution!
Additionally the returned object can be safely mutated but the input slice isn’t guaranteed to be mutable.
Finally, the returned object is disconnected from the input slice’s lifetime, so there’s no guarantee that the data is read at the right time.
Sourcepub unsafe fn view_mut_raw(ptr: *mut i16, length: usize) -> Int16Array
pub unsafe fn view_mut_raw(ptr: *mut i16, length: usize) -> Int16Array
Creates a JS typed array which is a view into wasm’s linear memory at the specified pointer with specified length.
This function returns a new typed array which is a view into wasm’s memory. This view does not copy the underlying data.
Safety
Views into WebAssembly memory are only valid so long as the
backing buffer isn’t resized in JS. Once this function is called
any future calls to Box::new (or malloc of any form) may cause
the returned value here to be invalidated. Use with caution!
Additionally the returned object can be safely mutated, the changes are guaranteed to be reflected in the input array.
Sourcepub unsafe fn raw_copy_to_ptr(&self, dst: *mut i16)
pub unsafe fn raw_copy_to_ptr(&self, dst: *mut i16)
Copy the contents of this JS typed array into the destination Rust pointer.
This function will efficiently copy the memory from a typed array into this Wasm module’s own linear memory, initializing the memory destination provided.
Safety
This function requires dst to point to a buffer
large enough to fit this array’s contents.
Sourcepub fn copy_to(&self, dst: &mut [i16])
pub fn copy_to(&self, dst: &mut [i16])
Copy the contents of this JS typed array into the destination Rust slice.
This function will efficiently copy the memory from a typed array into this Wasm module’s own linear memory, initializing the memory destination provided.
Panics
This function will panic if this typed array’s length is
different than the length of the provided dst array.
Sourcepub fn copy_to_uninit<'dst>(
&self,
dst: &'dst mut [MaybeUninit<i16>],
) -> &'dst mut [i16]
pub fn copy_to_uninit<'dst>( &self, dst: &'dst mut [MaybeUninit<i16>], ) -> &'dst mut [i16]
Copy the contents of this JS typed array into the destination Rust slice.
This function will efficiently copy the memory from a typed array into this Wasm module’s own linear memory, initializing the memory destination provided.
Panics
This function will panic if this typed array’s length is
different than the length of the provided dst array.
Sourcepub fn copy_from(&self, src: &[i16])
pub fn copy_from(&self, src: &[i16])
Copy the contents of the source Rust slice into this JS typed array.
This function will efficiently copy the memory from within the Wasm module’s own linear memory to this typed array.
Panics
This function will panic if this typed array’s length is
different than the length of the provided src array.
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.