JsString

Struct JsString 

#[repr(transparent)]
pub struct JsString { pub obj: JsValue, }

Fields

obj: JsValue

Implementations

Source

impl JsString

pub fn length(&self) -> u32

The length property of a String object indicates the length of a string, in UTF-16 code units.

MDN documentation

Source

impl JsString

pub fn at(&self, index: i32) -> Option<JsString>

The ‘at()’ method returns a new string consisting of the single UTF-16 code unit located at the specified offset into the string, counting from the end if it’s negative.

MDN documentation

Source

impl JsString

pub fn char_at(&self, index: u32) -> JsString

The String object’s charAt() method returns a new string consisting of the single UTF-16 code unit located at the specified offset into the string.

MDN documentation

Source

impl JsString

pub fn char_code_at(&self, index: u32) -> f64

The charCodeAt() method returns an integer between 0 and 65535 representing the UTF-16 code unit at the given index (the UTF-16 code unit matches the Unicode code point for code points representable in a single UTF-16 code unit, but might also be the first code unit of a surrogate pair for code points not representable in a single UTF-16 code unit, e.g. Unicode code points > 0x10000). If you want the entire code point value, use codePointAt().

Returns NaN if index is out of range.

MDN documentation

Source

impl JsString

pub fn code_point_at(&self, pos: u32) -> JsValue

The codePointAt() method returns a non-negative integer that is the Unicode code point value.

MDN documentation

Source

impl JsString

pub fn concat(&self, string_2: &JsValue) -> JsString

The concat() method concatenates the string arguments to the calling string and returns a new string.

MDN documentation

Source

impl JsString

pub fn ends_with(&self, search_string: &str, length: i32) -> bool

The endsWith() method determines whether a string ends with the characters of a specified string, returning true or false as appropriate.

MDN documentation

Source

impl JsString

pub fn from_char_code(char_codes: &[u16]) -> JsString

The static String.fromCharCode() method returns a string created from the specified sequence of UTF-16 code units.

MDN documentation

Notes

There are a few bindings to from_char_code in js-sys: from_char_code1, from_char_code2, etc… with different arities.

Additionally, this function accepts u16 for character codes, but fixing others requires a breaking change release (see https://github.com/wasm-bindgen/wasm-bindgen/issues/1460 for details).

Source

impl JsString

Source

impl JsString

Source

impl JsString

Source

impl JsString

Source

impl JsString

Source

impl JsString

pub fn from_code_point(code_points: &[u32]) -> Result<JsString, JsValue>

The static String.fromCodePoint() method returns a string created by using the specified sequence of code points.

MDN documentation

Exceptions

A RangeError is thrown if an invalid Unicode code point is given

Notes

There are a few bindings to from_code_point in js-sys: from_code_point1, from_code_point2, etc… with different arities.

Source

impl JsString

Source

impl JsString

Source

impl JsString

Source

impl JsString

Source

impl JsString

Source

impl JsString

pub fn includes(&self, search_string: &str, position: i32) -> bool

The includes() method determines whether one string may be found within another string, returning true or false as appropriate.

MDN documentation

Source

impl JsString

pub fn index_of(&self, search_value: &str, from_index: i32) -> i32

The indexOf() method returns the index within the calling String object of the first occurrence of the specified value, starting the search at fromIndex. Returns -1 if the value is not found.

MDN documentation

Source

impl JsString

pub fn last_index_of(&self, search_value: &str, from_index: i32) -> i32

The lastIndexOf() method returns the index within the calling String object of the last occurrence of the specified value, searching backwards from fromIndex. Returns -1 if the value is not found.

MDN documentation

Source

impl JsString

pub fn locale_compare( &self, compare_string: &str, locales: &Array, options: &Object, ) -> i32

The localeCompare() method returns a number indicating whether a reference string comes before or after or is the same as the given string in sort order.

MDN documentation

Source

impl JsString

pub fn match_(&self, pattern: &RegExp) -> Option<Object>

The match() method retrieves the matches when matching a string against a regular expression.

MDN documentation

Source

impl JsString

pub fn match_all(&self, pattern: &RegExp) -> Iterator

The match_all() method is similar to match(), but gives an iterator of exec() arrays, which preserve capture groups.

MDN documentation

Source

impl JsString

pub fn normalize(&self, form: &str) -> JsString

The normalize() method returns the Unicode Normalization Form of a given string (if the value isn’t a string, it will be converted to one first).

MDN documentation

Source

impl JsString

pub fn pad_end(&self, target_length: u32, pad_string: &str) -> JsString

The padEnd() method pads the current string with a given string (repeated, if needed) so that the resulting string reaches a given length. The padding is applied from the end (right) of the current string.

MDN documentation

Source

impl JsString

pub fn pad_start(&self, target_length: u32, pad_string: &str) -> JsString

The padStart() method pads the current string with another string (repeated, if needed) so that the resulting string reaches the given length. The padding is applied from the start (left) of the current string.

MDN documentation

Source

impl JsString

pub fn repeat(&self, count: i32) -> JsString

The repeat() method constructs and returns a new string which contains the specified number of copies of the string on which it was called, concatenated together.

MDN documentation

Source

impl JsString

pub fn replace(&self, pattern: &str, replacement: &str) -> JsString

The replace() method returns a new string with some or all matches of a pattern replaced by a replacement. The pattern can be a string or a RegExp, and the replacement can be a string or a function to be called for each match.

Note: The original string will remain unchanged.

MDN documentation

Source

impl JsString

pub fn replace_with_function( &self, pattern: &str, replacement: &Function, ) -> JsString

Source

impl JsString

pub fn replace_by_pattern( &self, pattern: &RegExp, replacement: &str, ) -> JsString

Source

impl JsString

Source

impl JsString

pub fn replace_all(&self, pattern: &str, replacement: &str) -> JsString

The replace_all() method returns a new string with all matches of a pattern replaced by a replacement. The pattern can be a string or a global RegExp, and the replacement can be a string or a function to be called for each match.

Note: The original string will remain unchanged.

MDN documentation

Source

impl JsString

pub fn replace_all_with_function( &self, pattern: &str, replacement: &Function, ) -> JsString

Source

impl JsString

pub fn replace_all_by_pattern( &self, pattern: &RegExp, replacement: &str, ) -> JsString

Source

impl JsString

Source

impl JsString

pub fn search(&self, pattern: &RegExp) -> i32

The search() method executes a search for a match between a regular expression and this String object.

MDN documentation

Source

impl JsString

pub fn slice(&self, start: u32, end: u32) -> JsString

The slice() method extracts a section of a string and returns it as a new string, without modifying the original string.

MDN documentation

Source

impl JsString

pub fn split(&self, separator: &str) -> Array

The split() method splits a String object into an array of strings by separating the string into substrings, using a specified separator string to determine where to make each split.

MDN documentation

Source

impl JsString

pub fn split_limit(&self, separator: &str, limit: u32) -> Array

Source

impl JsString

Source

impl JsString

pub fn split_by_pattern_limit(&self, pattern: &RegExp, limit: u32) -> Array

Source

impl JsString

pub fn starts_with(&self, search_string: &str, position: u32) -> bool

The startsWith() method determines whether a string begins with the characters of a specified string, returning true or false as appropriate.

MDN documentation

Source

impl JsString

pub fn substring(&self, index_start: u32, index_end: u32) -> JsString

The substring() method returns the part of the string between the start and end indexes, or to the end of the string.

MDN documentation

Source

impl JsString

pub fn substr(&self, start: i32, length: i32) -> JsString

The substr() method returns the part of a string between the start index and a number of characters after it.

MDN documentation

Source

impl JsString

pub fn to_locale_lower_case(&self, locale: Option<&str>) -> JsString

The toLocaleLowerCase() method returns the calling string value converted to lower case, according to any locale-specific case mappings.

MDN documentation

Source

impl JsString

pub fn to_locale_upper_case(&self, locale: Option<&str>) -> JsString

The toLocaleUpperCase() method returns the calling string value converted to upper case, according to any locale-specific case mappings.

MDN documentation

Source

impl JsString

pub fn to_lower_case(&self) -> JsString

The toLowerCase() method returns the calling string value converted to lower case.

MDN documentation

Source

impl JsString

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the specified object.

MDN documentation

Source

impl JsString

pub fn to_upper_case(&self) -> JsString

The toUpperCase() method returns the calling string value converted to uppercase (the value will be converted to a string if it isn’t one).

MDN documentation

Source

impl JsString

pub fn trim(&self) -> JsString

The trim() method removes whitespace from both ends of a string. Whitespace in this context is all the whitespace characters (space, tab, no-break space, etc.) and all the line terminator characters (LF, CR, etc.).

MDN documentation

Source

impl JsString

pub fn trim_end(&self) -> JsString

The trimEnd() method removes whitespace from the end of a string. trimRight() is an alias of this method.

MDN documentation

Source

impl JsString

pub fn trim_right(&self) -> JsString

The trimEnd() method removes whitespace from the end of a string. trimRight() is an alias of this method.

MDN documentation

Source

impl JsString

pub fn trim_start(&self) -> JsString

The trimStart() method removes whitespace from the beginning of a string. trimLeft() is an alias of this method.

MDN documentation

Source

impl JsString

pub fn trim_left(&self) -> JsString

The trimStart() method removes whitespace from the beginning of a string. trimLeft() is an alias of this method.

MDN documentation

Source

impl JsString

pub fn value_of(&self) -> JsString

The valueOf() method returns the primitive value of a String object.

MDN documentation

Source

impl JsString

pub fn raw( call_site: &Object, substitutions: &Array, ) -> Result<JsString, JsValue>

The static raw() method is a tag function of template literals, similar to the r prefix in Python or the @ prefix in C# for string literals.

MDN documentation

Source

impl JsString

pub fn raw_0(call_site: &Object) -> Result<JsString, JsValue>

The static raw() method is a tag function of template literals, similar to the r prefix in Python or the @ prefix in C# for string literals.

MDN documentation

Source

impl JsString

pub fn raw_1( call_site: &Object, substitutions_1: &str, ) -> Result<JsString, JsValue>

The static raw() method is a tag function of template literals, similar to the r prefix in Python or the @ prefix in C# for string literals.

MDN documentation

Source

impl JsString

pub fn raw_2( call_site: &Object, substitutions_1: &str, substitutions_2: &str, ) -> Result<JsString, JsValue>

The static raw() method is a tag function of template literals, similar to the r prefix in Python or the @ prefix in C# for string literals.

MDN documentation

Source

impl JsString

pub fn raw_3( call_site: &Object, substitutions_1: &str, substitutions_2: &str, substitutions_3: &str, ) -> Result<JsString, JsValue>

The static raw() method is a tag function of template literals, similar to the r prefix in Python or the @ prefix in C# for string literals.

MDN documentation

Source

impl JsString

pub fn raw_4( call_site: &Object, substitutions_1: &str, substitutions_2: &str, substitutions_3: &str, substitutions_4: &str, ) -> Result<JsString, JsValue>

The static raw() method is a tag function of template literals, similar to the r prefix in Python or the @ prefix in C# for string literals.

MDN documentation

Source

impl JsString

pub fn raw_5( call_site: &Object, substitutions_1: &str, substitutions_2: &str, substitutions_3: &str, substitutions_4: &str, substitutions_5: &str, ) -> Result<JsString, JsValue>

The static raw() method is a tag function of template literals, similar to the r prefix in Python or the @ prefix in C# for string literals.

MDN documentation

Source

impl JsString

pub fn raw_6( call_site: &Object, substitutions_1: &str, substitutions_2: &str, substitutions_3: &str, substitutions_4: &str, substitutions_5: &str, substitutions_6: &str, ) -> Result<JsString, JsValue>

The static raw() method is a tag function of template literals, similar to the r prefix in Python or the @ prefix in C# for string literals.

MDN documentation

Source

impl JsString

pub fn raw_7( call_site: &Object, substitutions_1: &str, substitutions_2: &str, substitutions_3: &str, substitutions_4: &str, substitutions_5: &str, substitutions_6: &str, substitutions_7: &str, ) -> Result<JsString, JsValue>

The static raw() method is a tag function of template literals, similar to the r prefix in Python or the @ prefix in C# for string literals.

MDN documentation

Source

impl JsString

pub fn try_from(val: &JsValue) -> Option<&JsString>

👎Deprecated: recommended to use dyn_ref instead which is now equivalent

Returns the JsString value of this JS value if it’s an instance of a string.

If this JS value is not an instance of a string then this returns None.

pub fn is_valid_utf16(&self) -> bool

Returns whether this string is a valid UTF-16 string.

This is useful for learning whether String::from(..) will return a lossless representation of the JS string. If this string contains unpaired surrogates then String::from will succeed but it will be a lossy representation of the JS string because unpaired surrogates will become replacement characters.

If this function returns false then to get a lossless representation of the string you’ll need to manually use the iter method (or the char_code_at accessor) to view the raw character codes.

For more information, see the documentation on JS strings vs Rust strings

pub fn iter( &self, ) -> impl ExactSizeIterator<Item = u16> + DoubleEndedIterator<Item = u16> + '_

Returns an iterator over the u16 character codes that make up this JS string.

This method will call char_code_at for each code in this JS string, returning an iterator of the codes in sequence.

pub fn as_char(&self) -> Option<char>

If this string consists of a single Unicode code point, then this method converts it into a Rust char without doing any allocations.

If this JS value is not a valid UTF-8 or consists of more than a single codepoint, then this returns None.

Note that a single Unicode code point might be represented as more than one code unit on the JavaScript side. For example, a JavaScript string "\uD801\uDC37" is actually a single Unicode code point U+10437 which corresponds to a character ‘𐐷’.

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

The constructor property returns a reference to the Object constructor function that created the instance object.

MDN documentation

pub fn has_own_property(&self, property: &JsValue) -> bool

The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).

MDN documentation

pub fn is_prototype_of(&self, value: &JsValue) -> bool

The isPrototypeOf() method checks if an object exists in another object’s prototype chain.

MDN documentation

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.

MDN documentation

pub fn to_locale_string(&self) -> JsString

The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.

MDN documentation

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn value_of(&self) -> Object

The valueOf() method returns the primitive value of the specified object.

MDN documentation

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn id(&self) -> u64

Get the heap ID for this value.

This is used internally for encoding values to send to JS.

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, rhs: &JsValue) -> bool

Less than comparison.

pub fn le(&self, rhs: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, rhs: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, rhs: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, rhs: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.