#[repr(transparent)]pub struct Object {
pub obj: JsValue,
}Fields
obj: JsValueImplementations
Sourceimpl Object
impl Object
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourceimpl Object
impl Object
Sourceimpl Object
impl Object
Sourceimpl Object
impl Object
Sourcepub fn define_properties(obj: &Object, props: &Object) -> Object
pub fn define_properties(obj: &Object, props: &Object) -> Object
The Object.defineProperties() method defines new or modifies
existing properties directly on an object, returning the
object.
Sourceimpl Object
impl Object
Sourcepub fn entries(object: &Object) -> Array
pub fn entries(object: &Object) -> Array
The Object.entries() method returns an array of a given
object’s own enumerable property [key, value] pairs, in the
same order as that provided by a for…in loop (the difference
being that a for-in loop enumerates properties in the
prototype chain as well).
Sourceimpl Object
impl Object
Sourcepub fn freeze(value: &Object) -> Object
pub fn freeze(value: &Object) -> Object
The Object.freeze() method freezes an object: that is, prevents new
properties from being added to it; prevents existing properties from
being removed; and prevents existing properties, or their enumerability,
configurability, or writability, from being changed, it also prevents
the prototype from being changed. The method returns the passed object.
Sourceimpl Object
impl Object
Sourceimpl Object
impl Object
Sourcepub fn get_own_property_descriptor(obj: &Object, prop: &JsValue) -> JsValue
pub fn get_own_property_descriptor(obj: &Object, prop: &JsValue) -> JsValue
The Object.getOwnPropertyDescriptor() method returns a
property descriptor for an own property (that is, one directly
present on an object and not in the object’s prototype chain)
of a given object.
Sourceimpl Object
impl Object
Sourcepub fn get_own_property_descriptors(obj: &Object) -> JsValue
pub fn get_own_property_descriptors(obj: &Object) -> JsValue
The Object.getOwnPropertyDescriptors() method returns all own
property descriptors of a given object.
Sourceimpl Object
impl Object
Sourcepub fn get_own_property_names(obj: &Object) -> Array
pub fn get_own_property_names(obj: &Object) -> Array
The Object.getOwnPropertyNames() method returns an array of
all properties (including non-enumerable properties except for
those which use Symbol) found directly upon a given object.
Sourceimpl Object
impl Object
Sourcepub fn get_own_property_symbols(obj: &Object) -> Array
pub fn get_own_property_symbols(obj: &Object) -> Array
The Object.getOwnPropertySymbols() method returns an array of
all symbol properties found directly upon a given object.
Sourceimpl Object
impl Object
Sourcepub fn get_prototype_of(obj: &JsValue) -> Object
pub fn get_prototype_of(obj: &JsValue) -> Object
The Object.getPrototypeOf() method returns the prototype
(i.e. the value of the internal [[Prototype]] property) of the
specified object.
Sourceimpl Object
impl Object
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourceimpl Object
impl Object
Sourcepub fn is_extensible(object: &Object) -> bool
pub fn is_extensible(object: &Object) -> bool
The Object.isExtensible() method determines if an object is extensible
(whether it can have new properties added to it).
Sourceimpl Object
impl Object
Sourceimpl Object
impl Object
Sourceimpl Object
impl Object
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourceimpl Object
impl Object
Sourceimpl Object
impl Object
Sourcepub fn prevent_extensions(object: &Object)
pub fn prevent_extensions(object: &Object)
The Object.preventExtensions() method prevents new properties from
ever being added to an object (i.e. prevents future extensions to the
object).
Sourceimpl Object
impl Object
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourceimpl Object
impl Object
Sourceimpl Object
impl Object
Sourcepub fn set_prototype_of(object: &Object, prototype: &Object) -> Object
pub fn set_prototype_of(object: &Object, prototype: &Object) -> Object
The Object.setPrototypeOf() method sets the prototype (i.e., the
internal [[Prototype]] property) of a specified object to another
object or null.
Sourceimpl Object
impl Object
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourceimpl Object
impl Object
Sourceimpl Object
impl Object
Sourceimpl Object
impl Object
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.