Uint8Array

Struct Uint8Array 

#[repr(transparent)]
pub struct Uint8Array { pub obj: JsValue, }

Fields

obj: JsValue

Implementations

Source

impl Uint8Array

pub fn new(constructor_arg: &JsValue) -> Uint8Array

The Uint8Array() constructor creates a new array.

MDN documentation

Source

impl Uint8Array

pub fn new_with_length(length: u32) -> Uint8Array

An Uint8Array() which creates an array with an internal buffer large enough for length elements.

MDN documentation

Source

impl Uint8Array

pub fn new_from_slice(slice: &[u8]) -> Uint8Array

An Uint8Array() which creates an array from a Rust slice.

MDN documentation

Source

impl Uint8Array

pub fn new_with_byte_offset(buffer: &JsValue, byte_offset: u32) -> Uint8Array

An Uint8Array() which creates an array with the given buffer but is a view starting at byte_offset.

MDN documentation

Source

impl Uint8Array

pub fn new_with_byte_offset_and_length( buffer: &JsValue, byte_offset: u32, length: u32, ) -> Uint8Array

An Uint8Array() which creates an array with the given buffer but is a view starting at byte_offset for length elements.

MDN documentation

Source

impl Uint8Array

pub fn fill(&self, value: u8, start: u32, end: u32) -> Uint8Array

The fill() method fills all the elements of an array from a start index to an end index with a static value. The end index is not included.

MDN documentation

Source

impl Uint8Array

pub fn buffer(&self) -> ArrayBuffer

The buffer accessor property represents the ArrayBuffer referenced by a TypedArray at construction time.

Source

impl Uint8Array

pub fn subarray(&self, begin: u32, end: u32) -> Uint8Array

The subarray() method returns a new TypedArray on the same ArrayBuffer store and with the same element types as for this TypedArray object.

Source

impl Uint8Array

pub fn slice(&self, begin: u32, end: u32) -> Uint8Array

The slice() method returns a shallow copy of a portion of a typed array into a new typed array object. This method has the same algorithm as Array.prototype.slice().

Source

impl Uint8Array

pub fn for_each(&self, callback: &mut dyn FnMut(u8, u32, Uint8Array))

The forEach() method executes a provided function once per array element. This method has the same algorithm as Array.prototype.forEach(). TypedArray is one of the typed array types here.

Source

impl Uint8Array

pub fn length(&self) -> u32

The length accessor property represents the length (in elements) of a typed array.

Source

impl Uint8Array

pub fn byte_length(&self) -> u32

The byteLength accessor property represents the length (in bytes) of a typed array.

Source

impl Uint8Array

pub fn byte_offset(&self) -> u32

The byteOffset accessor property represents the offset (in bytes) of a typed array from the start of its ArrayBuffer.

Source

impl Uint8Array

pub fn set(&self, src: &JsValue, offset: u32)

The set() method stores multiple values in the typed array, reading input values from a specified array.

Source

impl Uint8Array

pub fn at(&self, idx: i32) -> Option<u8>

Gets the value at idx, counting from the end if negative.

Source

impl Uint8Array

pub fn copy_within(&self, target: i32, start: i32, end: i32) -> Uint8Array

The copyWithin() method shallow copies part of a typed array to another location in the same typed array and returns it, without modifying its size.

MDN documentation

Source

impl Uint8Array

pub fn get_index(&self, idx: u32) -> u8

Gets the value at idx, equivalent to the javascript my_var = arr[idx].

Source

impl Uint8Array

pub fn set_index(&self, idx: u32, value: u8)

Sets the value at idx, equivalent to the javascript arr[idx] = value.

Source

impl Uint8Array

pub unsafe fn view(rust: &[u8]) -> Uint8Array

Creates a JS typed array which is a view into wasm’s linear memory at the slice specified.

This function returns a new typed array which is a view into wasm’s memory. This view does not copy the underlying data.

Safety

Views into WebAssembly memory are only valid so long as the backing buffer isn’t resized in JS. Once this function is called any future calls to Box::new (or malloc of any form) may cause the returned value here to be invalidated. Use with caution!

Additionally the returned object can be safely mutated but the input slice isn’t guaranteed to be mutable.

Finally, the returned object is disconnected from the input slice’s lifetime, so there’s no guarantee that the data is read at the right time.

pub unsafe fn view_mut_raw(ptr: *mut u8, length: usize) -> Uint8Array

Creates a JS typed array which is a view into wasm’s linear memory at the specified pointer with specified length.

This function returns a new typed array which is a view into wasm’s memory. This view does not copy the underlying data.

Safety

Views into WebAssembly memory are only valid so long as the backing buffer isn’t resized in JS. Once this function is called any future calls to Box::new (or malloc of any form) may cause the returned value here to be invalidated. Use with caution!

Additionally the returned object can be safely mutated, the changes are guaranteed to be reflected in the input array.

pub unsafe fn raw_copy_to_ptr(&self, dst: *mut u8)

Copy the contents of this JS typed array into the destination Rust pointer.

This function will efficiently copy the memory from a typed array into this Wasm module’s own linear memory, initializing the memory destination provided.

Safety

This function requires dst to point to a buffer large enough to fit this array’s contents.

pub fn copy_to(&self, dst: &mut [u8])

Copy the contents of this JS typed array into the destination Rust slice.

This function will efficiently copy the memory from a typed array into this Wasm module’s own linear memory, initializing the memory destination provided.

Panics

This function will panic if this typed array’s length is different than the length of the provided dst array.

pub fn copy_to_uninit<'dst>( &self, dst: &'dst mut [MaybeUninit<u8>], ) -> &'dst mut [u8]

Copy the contents of this JS typed array into the destination Rust slice.

This function will efficiently copy the memory from a typed array into this Wasm module’s own linear memory, initializing the memory destination provided.

Panics

This function will panic if this typed array’s length is different than the length of the provided dst array.

pub fn copy_from(&self, src: &[u8])

Copy the contents of the source Rust slice into this JS typed array.

This function will efficiently copy the memory from within the Wasm module’s own linear memory to this typed array.

Panics

This function will panic if this typed array’s length is different than the length of the provided src array.

pub fn to_vec(&self) -> Vec<u8>

Efficiently copies the contents of this JS typed array into a new Vec.

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

The constructor property returns a reference to the Object constructor function that created the instance object.

MDN documentation

pub fn has_own_property(&self, property: &JsValue) -> bool

The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).

MDN documentation

pub fn is_prototype_of(&self, value: &JsValue) -> bool

The isPrototypeOf() method checks if an object exists in another object’s prototype chain.

MDN documentation

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.

MDN documentation

pub fn to_locale_string(&self) -> JsString

The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.

MDN documentation

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn value_of(&self) -> Object

The valueOf() method returns the primitive value of the specified object.

MDN documentation

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn id(&self) -> u64

Get the heap ID for this value.

This is used internally for encoding values to send to JS.

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, rhs: &JsValue) -> bool

Less than comparison.

pub fn le(&self, rhs: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, rhs: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, rhs: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, rhs: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.