#[repr(transparent)]pub struct DataView {
pub obj: JsValue,
}Fields
obj: JsValueImplementations
Sourceimpl DataView
impl DataView
Sourceimpl DataView
impl DataView
The DataView view provides a low-level interface for reading and
writing multiple number types in an ArrayBuffer irrespective of the
platform’s endianness.
Sourceimpl DataView
impl DataView
Sourcepub fn buffer(&self) -> ArrayBuffer
pub fn buffer(&self) -> ArrayBuffer
The ArrayBuffer referenced by this view. Fixed at construction time and thus read only.
Sourceimpl DataView
impl DataView
Sourcepub fn byte_length(&self) -> usize
pub fn byte_length(&self) -> usize
The length (in bytes) of this view from the start of its ArrayBuffer. Fixed at construction time and thus read only.
Sourceimpl DataView
impl DataView
Sourcepub fn byte_offset(&self) -> usize
pub fn byte_offset(&self) -> usize
The offset (in bytes) of this view from the start of its ArrayBuffer. Fixed at construction time and thus read only.
Sourceimpl DataView
impl DataView
Sourceimpl DataView
impl DataView
Sourceimpl DataView
impl DataView
Sourceimpl DataView
impl DataView
Sourcepub fn get_int16_endian(&self, byte_offset: usize, little_endian: bool) -> i16
pub fn get_int16_endian(&self, byte_offset: usize, little_endian: bool) -> i16
The getInt16() method gets a signed 16-bit integer (short) at the specified
byte offset from the start of the DataView.
Sourceimpl DataView
impl DataView
Sourcepub fn get_uint16(&self, byte_offset: usize) -> u16
pub fn get_uint16(&self, byte_offset: usize) -> u16
The getUint16() method gets an unsigned 16-bit integer (unsigned short) at the specified
byte offset from the start of the view.
Sourceimpl DataView
impl DataView
Sourcepub fn get_uint16_endian(&self, byte_offset: usize, little_endian: bool) -> u16
pub fn get_uint16_endian(&self, byte_offset: usize, little_endian: bool) -> u16
The getUint16() method gets an unsigned 16-bit integer (unsigned short) at the specified
byte offset from the start of the view.
Sourceimpl DataView
impl DataView
Sourceimpl DataView
impl DataView
Sourcepub fn get_int32_endian(&self, byte_offset: usize, little_endian: bool) -> i32
pub fn get_int32_endian(&self, byte_offset: usize, little_endian: bool) -> i32
The getInt32() method gets a signed 32-bit integer (long) at the specified
byte offset from the start of the DataView.
Sourceimpl DataView
impl DataView
Sourcepub fn get_uint32(&self, byte_offset: usize) -> u32
pub fn get_uint32(&self, byte_offset: usize) -> u32
The getUint32() method gets an unsigned 32-bit integer (unsigned long) at the specified
byte offset from the start of the view.
Sourceimpl DataView
impl DataView
Sourcepub fn get_uint32_endian(&self, byte_offset: usize, little_endian: bool) -> u32
pub fn get_uint32_endian(&self, byte_offset: usize, little_endian: bool) -> u32
The getUint32() method gets an unsigned 32-bit integer (unsigned long) at the specified
byte offset from the start of the view.
Sourceimpl DataView
impl DataView
Sourcepub fn get_float32(&self, byte_offset: usize) -> f32
pub fn get_float32(&self, byte_offset: usize) -> f32
The getFloat32() method gets a signed 32-bit float (float) at the specified
byte offset from the start of the DataView.
Sourceimpl DataView
impl DataView
Sourcepub fn get_float32_endian(&self, byte_offset: usize, little_endian: bool) -> f32
pub fn get_float32_endian(&self, byte_offset: usize, little_endian: bool) -> f32
The getFloat32() method gets a signed 32-bit float (float) at the specified
byte offset from the start of the DataView.
Sourceimpl DataView
impl DataView
Sourcepub fn get_float64(&self, byte_offset: usize) -> f64
pub fn get_float64(&self, byte_offset: usize) -> f64
The getFloat64() method gets a signed 64-bit float (double) at the specified
byte offset from the start of the DataView.
Sourceimpl DataView
impl DataView
Sourcepub fn get_float64_endian(&self, byte_offset: usize, little_endian: bool) -> f64
pub fn get_float64_endian(&self, byte_offset: usize, little_endian: bool) -> f64
The getFloat64() method gets a signed 64-bit float (double) at the specified
byte offset from the start of the DataView.
Sourceimpl DataView
impl DataView
Sourceimpl DataView
impl DataView
Sourceimpl DataView
impl DataView
Sourceimpl DataView
impl DataView
Sourcepub fn set_int16_endian(
&self,
byte_offset: usize,
value: i16,
little_endian: bool,
)
pub fn set_int16_endian( &self, byte_offset: usize, value: i16, little_endian: bool, )
The setInt16() method stores a signed 16-bit integer (short) value at the
specified byte offset from the start of the DataView.
Sourceimpl DataView
impl DataView
Sourcepub fn set_uint16(&self, byte_offset: usize, value: u16)
pub fn set_uint16(&self, byte_offset: usize, value: u16)
The setUint16() method stores an unsigned 16-bit integer (unsigned short) value at the
specified byte offset from the start of the DataView.
Sourceimpl DataView
impl DataView
Sourcepub fn set_uint16_endian(
&self,
byte_offset: usize,
value: u16,
little_endian: bool,
)
pub fn set_uint16_endian( &self, byte_offset: usize, value: u16, little_endian: bool, )
The setUint16() method stores an unsigned 16-bit integer (unsigned short) value at the
specified byte offset from the start of the DataView.
Sourceimpl DataView
impl DataView
Sourceimpl DataView
impl DataView
Sourcepub fn set_int32_endian(
&self,
byte_offset: usize,
value: i32,
little_endian: bool,
)
pub fn set_int32_endian( &self, byte_offset: usize, value: i32, little_endian: bool, )
The setInt32() method stores a signed 32-bit integer (long) value at the
specified byte offset from the start of the DataView.
Sourceimpl DataView
impl DataView
Sourcepub fn set_uint32(&self, byte_offset: usize, value: u32)
pub fn set_uint32(&self, byte_offset: usize, value: u32)
The setUint32() method stores an unsigned 32-bit integer (unsigned long) value at the
specified byte offset from the start of the DataView.
Sourceimpl DataView
impl DataView
Sourcepub fn set_uint32_endian(
&self,
byte_offset: usize,
value: u32,
little_endian: bool,
)
pub fn set_uint32_endian( &self, byte_offset: usize, value: u32, little_endian: bool, )
The setUint32() method stores an unsigned 32-bit integer (unsigned long) value at the
specified byte offset from the start of the DataView.
Sourceimpl DataView
impl DataView
Sourcepub fn set_float32(&self, byte_offset: usize, value: f32)
pub fn set_float32(&self, byte_offset: usize, value: f32)
The setFloat32() method stores a signed 32-bit float (float) value at the
specified byte offset from the start of the DataView.
Sourceimpl DataView
impl DataView
Sourcepub fn set_float32_endian(
&self,
byte_offset: usize,
value: f32,
little_endian: bool,
)
pub fn set_float32_endian( &self, byte_offset: usize, value: f32, little_endian: bool, )
The setFloat32() method stores a signed 32-bit float (float) value at the
specified byte offset from the start of the DataView.
Sourceimpl DataView
impl DataView
Sourcepub fn set_float64(&self, byte_offset: usize, value: f64)
pub fn set_float64(&self, byte_offset: usize, value: f64)
The setFloat64() method stores a signed 64-bit float (double) value at the
specified byte offset from the start of the DataView.
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.