#[repr(transparent)]pub struct JsString {
pub obj: JsValue,
}Fields
obj: JsValueImplementations
Sourceimpl JsString
impl JsString
Sourceimpl JsString
impl JsString
Sourceimpl JsString
impl JsString
Sourcepub fn char_code_at(&self, index: u32) -> f64
pub fn char_code_at(&self, index: u32) -> f64
The charCodeAt() method returns an integer between 0 and 65535
representing the UTF-16 code unit at the given index (the UTF-16 code
unit matches the Unicode code point for code points representable in a
single UTF-16 code unit, but might also be the first code unit of a
surrogate pair for code points not representable in a single UTF-16 code
unit, e.g. Unicode code points > 0x10000). If you want the entire code
point value, use codePointAt().
Returns NaN if index is out of range.
Sourceimpl JsString
impl JsString
Sourcepub fn code_point_at(&self, pos: u32) -> JsValue
pub fn code_point_at(&self, pos: u32) -> JsValue
The codePointAt() method returns a non-negative integer that is the
Unicode code point value.
Sourceimpl JsString
impl JsString
Sourceimpl JsString
impl JsString
Sourcepub fn from_char_code(char_codes: &[u16]) -> JsString
pub fn from_char_code(char_codes: &[u16]) -> JsString
The static String.fromCharCode() method returns a string created from
the specified sequence of UTF-16 code units.
Notes
There are a few bindings to from_char_code in js-sys: from_char_code1, from_char_code2, etc…
with different arities.
Additionally, this function accepts u16 for character codes, but
fixing others requires a breaking change release
(see https://github.com/wasm-bindgen/wasm-bindgen/issues/1460 for details).
Sourceimpl JsString
impl JsString
Sourceimpl JsString
impl JsString
Sourcepub fn from_code_point(code_points: &[u32]) -> Result<JsString, JsValue>
pub fn from_code_point(code_points: &[u32]) -> Result<JsString, JsValue>
The static String.fromCodePoint() method returns a string created by
using the specified sequence of code points.
Exceptions
A RangeError is thrown if an invalid Unicode code point is given
Notes
There are a few bindings to from_code_point in js-sys: from_code_point1, from_code_point2, etc…
with different arities.
Sourceimpl JsString
impl JsString
Sourceimpl JsString
impl JsString
Sourceimpl JsString
impl JsString
Sourcepub fn last_index_of(&self, search_value: &str, from_index: i32) -> i32
pub fn last_index_of(&self, search_value: &str, from_index: i32) -> i32
The lastIndexOf() method returns the index within the calling String
object of the last occurrence of the specified value, searching
backwards from fromIndex. Returns -1 if the value is not found.
Sourceimpl JsString
impl JsString
Sourceimpl JsString
impl JsString
Sourceimpl JsString
impl JsString
Sourceimpl JsString
impl JsString
Sourceimpl JsString
impl JsString
Sourceimpl JsString
impl JsString
Sourceimpl JsString
impl JsString
Sourcepub fn replace(&self, pattern: &str, replacement: &str) -> JsString
pub fn replace(&self, pattern: &str, replacement: &str) -> JsString
The replace() method returns a new string with some or all matches of a pattern
replaced by a replacement. The pattern can be a string or a RegExp, and
the replacement can be a string or a function to be called for each match.
Note: The original string will remain unchanged.
Sourceimpl JsString
impl JsString
Sourcepub fn replace_with_function(
&self,
pattern: &str,
replacement: &Function,
) -> JsString
pub fn replace_with_function( &self, pattern: &str, replacement: &Function, ) -> JsString
Sourceimpl JsString
impl JsString
pub fn replace_by_pattern( &self, pattern: &RegExp, replacement: &str, ) -> JsString
Sourceimpl JsString
impl JsString
Sourcepub fn replace_by_pattern_with_function(
&self,
pattern: &RegExp,
replacement: &Function,
) -> JsString
pub fn replace_by_pattern_with_function( &self, pattern: &RegExp, replacement: &Function, ) -> JsString
Sourceimpl JsString
impl JsString
Sourcepub fn replace_all(&self, pattern: &str, replacement: &str) -> JsString
pub fn replace_all(&self, pattern: &str, replacement: &str) -> JsString
The replace_all() method returns a new string with all matches of a pattern
replaced by a replacement. The pattern can be a string or a global RegExp, and
the replacement can be a string or a function to be called for each match.
Note: The original string will remain unchanged.
Sourceimpl JsString
impl JsString
Sourcepub fn replace_all_with_function(
&self,
pattern: &str,
replacement: &Function,
) -> JsString
pub fn replace_all_with_function( &self, pattern: &str, replacement: &Function, ) -> JsString
Sourceimpl JsString
impl JsString
pub fn replace_all_by_pattern( &self, pattern: &RegExp, replacement: &str, ) -> JsString
Sourceimpl JsString
impl JsString
Sourcepub fn replace_all_by_pattern_with_function(
&self,
pattern: &RegExp,
replacement: &Function,
) -> JsString
pub fn replace_all_by_pattern_with_function( &self, pattern: &RegExp, replacement: &Function, ) -> JsString
Sourceimpl JsString
impl JsString
Sourceimpl JsString
impl JsString
Sourceimpl JsString
impl JsString
Sourcepub fn split_by_pattern_limit(&self, pattern: &RegExp, limit: u32) -> Array
pub fn split_by_pattern_limit(&self, pattern: &RegExp, limit: u32) -> Array
Sourceimpl JsString
impl JsString
Sourcepub fn starts_with(&self, search_string: &str, position: u32) -> bool
pub fn starts_with(&self, search_string: &str, position: u32) -> bool
The startsWith() method determines whether a string begins with the
characters of a specified string, returning true or false as
appropriate.
Sourceimpl JsString
impl JsString
Sourcepub fn to_locale_lower_case(&self, locale: Option<&str>) -> JsString
pub fn to_locale_lower_case(&self, locale: Option<&str>) -> JsString
The toLocaleLowerCase() method returns the calling string value converted to lower case,
according to any locale-specific case mappings.
Sourceimpl JsString
impl JsString
Sourcepub fn to_locale_upper_case(&self, locale: Option<&str>) -> JsString
pub fn to_locale_upper_case(&self, locale: Option<&str>) -> JsString
The toLocaleUpperCase() method returns the calling string value converted to upper case,
according to any locale-specific case mappings.
Sourceimpl JsString
impl JsString
Sourcepub fn to_lower_case(&self) -> JsString
pub fn to_lower_case(&self) -> JsString
The toLowerCase() method returns the calling string value
converted to lower case.
Sourceimpl JsString
impl JsString
Sourceimpl JsString
impl JsString
Sourcepub fn to_upper_case(&self) -> JsString
pub fn to_upper_case(&self) -> JsString
The toUpperCase() method returns the calling string value converted to
uppercase (the value will be converted to a string if it isn’t one).
Sourceimpl JsString
impl JsString
Sourceimpl JsString
impl JsString
Sourceimpl JsString
impl JsString
Sourcepub fn trim_right(&self) -> JsString
pub fn trim_right(&self) -> JsString
The trimEnd() method removes whitespace from the end of a string.
trimRight() is an alias of this method.
Sourceimpl JsString
impl JsString
Sourcepub fn trim_start(&self) -> JsString
pub fn trim_start(&self) -> JsString
The trimStart() method removes whitespace from the beginning of a
string. trimLeft() is an alias of this method.
Sourceimpl JsString
impl JsString
Sourceimpl JsString
impl JsString
Sourceimpl JsString
impl JsString
Sourcepub fn raw_4(
call_site: &Object,
substitutions_1: &str,
substitutions_2: &str,
substitutions_3: &str,
substitutions_4: &str,
) -> Result<JsString, JsValue>
pub fn raw_4( call_site: &Object, substitutions_1: &str, substitutions_2: &str, substitutions_3: &str, substitutions_4: &str, ) -> Result<JsString, JsValue>
The static raw() method is a tag function of template literals,
similar to the r prefix in Python or the @ prefix in C# for string literals.
Sourceimpl JsString
impl JsString
Sourcepub fn raw_5(
call_site: &Object,
substitutions_1: &str,
substitutions_2: &str,
substitutions_3: &str,
substitutions_4: &str,
substitutions_5: &str,
) -> Result<JsString, JsValue>
pub fn raw_5( call_site: &Object, substitutions_1: &str, substitutions_2: &str, substitutions_3: &str, substitutions_4: &str, substitutions_5: &str, ) -> Result<JsString, JsValue>
The static raw() method is a tag function of template literals,
similar to the r prefix in Python or the @ prefix in C# for string literals.
Sourceimpl JsString
impl JsString
Sourcepub fn raw_6(
call_site: &Object,
substitutions_1: &str,
substitutions_2: &str,
substitutions_3: &str,
substitutions_4: &str,
substitutions_5: &str,
substitutions_6: &str,
) -> Result<JsString, JsValue>
pub fn raw_6( call_site: &Object, substitutions_1: &str, substitutions_2: &str, substitutions_3: &str, substitutions_4: &str, substitutions_5: &str, substitutions_6: &str, ) -> Result<JsString, JsValue>
The static raw() method is a tag function of template literals,
similar to the r prefix in Python or the @ prefix in C# for string literals.
Sourceimpl JsString
impl JsString
Sourcepub fn raw_7(
call_site: &Object,
substitutions_1: &str,
substitutions_2: &str,
substitutions_3: &str,
substitutions_4: &str,
substitutions_5: &str,
substitutions_6: &str,
substitutions_7: &str,
) -> Result<JsString, JsValue>
pub fn raw_7( call_site: &Object, substitutions_1: &str, substitutions_2: &str, substitutions_3: &str, substitutions_4: &str, substitutions_5: &str, substitutions_6: &str, substitutions_7: &str, ) -> Result<JsString, JsValue>
The static raw() method is a tag function of template literals,
similar to the r prefix in Python or the @ prefix in C# for string literals.
Sourceimpl JsString
impl JsString
Sourcepub fn try_from(val: &JsValue) -> Option<&JsString>
👎Deprecated: recommended to use dyn_ref instead which is now equivalent
pub fn try_from(val: &JsValue) -> Option<&JsString>
Returns the JsString value of this JS value if it’s an instance of a
string.
If this JS value is not an instance of a string then this returns
None.
Sourcepub fn is_valid_utf16(&self) -> bool
pub fn is_valid_utf16(&self) -> bool
Returns whether this string is a valid UTF-16 string.
This is useful for learning whether String::from(..) will return a
lossless representation of the JS string. If this string contains
unpaired surrogates then String::from will succeed but it will be a
lossy representation of the JS string because unpaired surrogates will
become replacement characters.
If this function returns false then to get a lossless representation
of the string you’ll need to manually use the iter method (or the
char_code_at accessor) to view the raw character codes.
For more information, see the documentation on JS strings vs Rust strings
Sourcepub fn iter(
&self,
) -> impl ExactSizeIterator<Item = u16> + DoubleEndedIterator<Item = u16> + '_
pub fn iter( &self, ) -> impl ExactSizeIterator<Item = u16> + DoubleEndedIterator<Item = u16> + '_
Returns an iterator over the u16 character codes that make up this JS
string.
This method will call char_code_at for each code in this JS string,
returning an iterator of the codes in sequence.
Sourcepub fn as_char(&self) -> Option<char>
pub fn as_char(&self) -> Option<char>
If this string consists of a single Unicode code point, then this method
converts it into a Rust char without doing any allocations.
If this JS value is not a valid UTF-8 or consists of more than a single
codepoint, then this returns None.
Note that a single Unicode code point might be represented as more than
one code unit on the JavaScript side. For example, a JavaScript string
"\uD801\uDC37" is actually a single Unicode code point U+10437 which
corresponds to a character ‘𐐷’.
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.