#[repr(transparent)]pub struct Promise {
pub obj: JsValue,
}Expand description
The Promise object represents the eventual completion (or failure) of
an asynchronous operation, and its resulting value.
Fields
obj: JsValueImplementations
Sourceimpl Promise
impl Promise
Sourcepub fn new(cb: &mut dyn FnMut(Function, Function)) -> Promise
pub fn new(cb: &mut dyn FnMut(Function, Function)) -> Promise
Creates a new Promise with the provided executor cb
The cb is a function that is passed with the arguments resolve and
reject. The cb function is executed immediately by the Promise
implementation, passing resolve and reject functions (the executor
is called before the Promise constructor even returns the created
object). The resolve and reject functions, when called, resolve or
reject the promise, respectively. The executor normally initiates
some asynchronous work, and then, once that completes, either calls
the resolve function to resolve the promise or else rejects it if an
error occurred.
If an error is thrown in the executor function, the promise is rejected. The return value of the executor is ignored.
Sourceimpl Promise
impl Promise
Sourceimpl Promise
impl Promise
Sourcepub fn all_settled(obj: &JsValue) -> Promise
pub fn all_settled(obj: &JsValue) -> Promise
The Promise.allSettled(iterable) method returns a single Promise that
resolves when all of the promises in the iterable argument have either
fulfilled or rejected or when the iterable argument contains no promises.
Sourceimpl Promise
impl Promise
Sourcepub fn any(obj: &JsValue) -> Promise
pub fn any(obj: &JsValue) -> Promise
The Promise.any(iterable) method returns a single Promise that
resolves when any of the promises in the iterable argument have resolved
or when the iterable argument contains no promises. It rejects with an
AggregateError if all promises in the iterable rejected.
Sourceimpl Promise
impl Promise
Sourceimpl Promise
impl Promise
Sourceimpl Promise
impl Promise
Sourcepub fn resolve(obj: &JsValue) -> Promise
pub fn resolve(obj: &JsValue) -> Promise
The Promise.resolve(value) method returns a Promise object that is
resolved with the given value. If the value is a promise, that promise
is returned; if the value is a thenable (i.e. has a “then” method), the
returned promise will “follow” that thenable, adopting its eventual
state; otherwise the returned promise will be fulfilled with the value.
Sourceimpl Promise
impl Promise
Sourcepub fn catch(&self, cb: &Closure<dyn FnMut(JsValue)>) -> Promise
pub fn catch(&self, cb: &Closure<dyn FnMut(JsValue)>) -> Promise
The catch() method returns a Promise and deals with rejected cases
only. It behaves the same as calling Promise.prototype.then(undefined, onRejected) (in fact, calling obj.catch(onRejected) internally calls
obj.then(undefined, onRejected)).
Sourceimpl Promise
impl Promise
Sourcepub fn finally(&self, cb: &Closure<dyn FnMut()>) -> Promise
pub fn finally(&self, cb: &Closure<dyn FnMut()>) -> Promise
The finally() method returns a Promise. When the promise is settled,
whether fulfilled or rejected, the specified callback function is
executed. This provides a way for code that must be executed once the
Promise has been dealt with to be run whether the promise was
fulfilled successfully or rejected.
This lets you avoid duplicating code in both the promise’s then() and
catch() handlers.
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.